@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="nb">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nb">
 <context>
     <name>MainWindow</name>
     <message>
@@ -45,7 +43,7 @@
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="134"/>
-        <location filename="../src/gui/mainwindow.cpp" line="423"/>
+        <location filename="../src/gui/mainwindow.cpp" line="425"/>
         <source>Select Boot Method</source>
         <translation>Velg oppstartsmetode</translation>
     </message>
@@ -67,7 +65,7 @@
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="193"/>
-        <location filename="../src/gui/mainwindow.cpp" line="424"/>
+        <location filename="../src/gui/mainwindow.cpp" line="426"/>
         <source>Location:</source>
         <translation>Plassering:</translation>
     </message>
@@ -88,19 +86,19 @@
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="243"/>
-        <location filename="../src/gui/mainwindow.cpp" line="426"/>
+        <location filename="../src/gui/mainwindow.cpp" line="428"/>
         <source>root</source>
         <translation>rot</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="278"/>
-        <location filename="../src/gui/mainwindow.cpp" line="431"/>
+        <location filename="../src/gui/mainwindow.cpp" line="433"/>
         <source>Select root location:</source>
         <translation>Velg rotplassering:</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="300"/>
-        <location filename="../src/gui/mainwindow.cpp" line="425"/>
+        <location filename="../src/gui/mainwindow.cpp" line="427"/>
         <source>Install on:</source>
         <translation>Installer til:</translation>
     </message>
@@ -156,7 +154,7 @@
         <translation>Neste</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="459"/>
+        <location filename="../src/gui/mainwindow.cpp" line="461"/>
         <source>Apply</source>
         <translation>Bruk</translation>
     </message>
@@ -166,49 +164,49 @@
         <translation>GRUB installeres nå på enheten %1.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="290"/>
-        <location filename="../src/gui/mainwindow.cpp" line="348"/>
-        <location filename="../src/gui/mainwindow.cpp" line="464"/>
-        <location filename="../src/gui/mainwindow.cpp" line="468"/>
-        <location filename="../src/gui/mainwindow.cpp" line="475"/>
-        <location filename="../src/gui/mainwindow.cpp" line="481"/>
-        <location filename="../src/gui/mainwindow.cpp" line="489"/>
-        <location filename="../src/gui/mainwindow.cpp" line="496"/>
+        <location filename="../src/gui/mainwindow.cpp" line="292"/>
+        <location filename="../src/gui/mainwindow.cpp" line="350"/>
+        <location filename="../src/gui/mainwindow.cpp" line="466"/>
+        <location filename="../src/gui/mainwindow.cpp" line="470"/>
+        <location filename="../src/gui/mainwindow.cpp" line="477"/>
+        <location filename="../src/gui/mainwindow.cpp" line="483"/>
+        <location filename="../src/gui/mainwindow.cpp" line="491"/>
+        <location filename="../src/gui/mainwindow.cpp" line="498"/>
         <source>Error</source>
         <translation>Feil</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="140"/>
+        <location filename="../src/gui/mainwindow.cpp" line="142"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
         <translation>Gjenoppbygger oppsettsfila til GRUB (grub.cfg).</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="174"/>
+        <location filename="../src/gui/mainwindow.cpp" line="176"/>
         <source>Generating initramfs images on: %1</source>
         <translation>Genererer initramfs-bilder på: %1</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="203"/>
+        <location filename="../src/gui/mainwindow.cpp" line="205"/>
         <source>Backing up MBR or PBR from %1 device.</source>
         <translation>Reservekopierer MBR eller PBR fra enheten %1.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="259"/>
+        <location filename="../src/gui/mainwindow.cpp" line="261"/>
         <source>Warning</source>
         <translation>Advarsel</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="260"/>
+        <location filename="../src/gui/mainwindow.cpp" line="262"/>
         <source>You are going to write the content of </source>
         <translation>Nå skal innholdet i</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="260"/>
+        <location filename="../src/gui/mainwindow.cpp" line="262"/>
         <source> to </source>
         <translation>skrives til</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="261"/>
+        <location filename="../src/gui/mainwindow.cpp" line="263"/>
         <source>
 
 Are you sure?</source>
@@ -217,122 +215,122 @@ Are you sure?</source>
 Er du sikker?</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="267"/>
+        <location filename="../src/gui/mainwindow.cpp" line="269"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
         <translation>Gjenoppretter MBR/PBR fra reservekopi til enheten %1.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="291"/>
+        <location filename="../src/gui/mainwindow.cpp" line="293"/>
         <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
         <translation>Fant ikke EFI systempartisjon (ESP) på noen systemdisker. Opprett en ESP og forsøk igjen.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="303"/>
+        <location filename="../src/gui/mainwindow.cpp" line="305"/>
         <source>Select %1 location:</source>
         <translation>Velg plasseringen til %1:</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="326"/>
+        <location filename="../src/gui/mainwindow.cpp" line="328"/>
         <source>Back</source>
         <translation>Tilbake</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="342"/>
+        <location filename="../src/gui/mainwindow.cpp" line="344"/>
         <source>Success</source>
         <translation>Vellykket</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="342"/>
+        <location filename="../src/gui/mainwindow.cpp" line="344"/>
         <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
         <translation>Fullført uten feil. &lt;p&gt;&lt;b&gt;Vil du avslutte MX Oppstartsreparasjon?&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="348"/>
+        <location filename="../src/gui/mainwindow.cpp" line="350"/>
         <source>Process finished. Errors have occurred.</source>
         <translation>Prosessen er fullført. Det oppstod feil.</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="109"/>
-        <location filename="../src/gui/mainwindow.cpp" line="148"/>
-        <location filename="../src/gui/mainwindow.cpp" line="180"/>
+        <location filename="../src/gui/mainwindow.cpp" line="150"/>
+        <location filename="../src/gui/mainwindow.cpp" line="182"/>
         <source>Enter password to unlock %1 encrypted partition:</source>
         <translation>Angi passord for å låse opp den krypterte partisjonen %1:</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="430"/>
+        <location filename="../src/gui/mainwindow.cpp" line="432"/>
         <source>Select GRUB location</source>
         <translation>Velg GRUB-plassering</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="439"/>
+        <location filename="../src/gui/mainwindow.cpp" line="441"/>
         <source>Select initramfs options</source>
         <translation>Velg initramfs-alternativer</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="449"/>
+        <location filename="../src/gui/mainwindow.cpp" line="451"/>
         <source>Select Item to Back Up</source>
         <translation>Velg et element som skal reservekopieres</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="454"/>
+        <location filename="../src/gui/mainwindow.cpp" line="456"/>
         <source>Select Item to Restore</source>
         <translation>Velg et element som skal gjenopprettes</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="464"/>
-        <location filename="../src/gui/mainwindow.cpp" line="475"/>
+        <location filename="../src/gui/mainwindow.cpp" line="466"/>
+        <location filename="../src/gui/mainwindow.cpp" line="477"/>
         <source>No location was selected.</source>
         <translation>Ingen plassering er valgt.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="469"/>
-        <location filename="../src/gui/mainwindow.cpp" line="482"/>
+        <location filename="../src/gui/mainwindow.cpp" line="471"/>
+        <location filename="../src/gui/mainwindow.cpp" line="484"/>
         <source>Please select the root partition of the system you want to fix.</source>
         <translation>Velg rotpartisjonen til systemet som skal fikses.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="487"/>
+        <location filename="../src/gui/mainwindow.cpp" line="489"/>
         <source>Select backup file name</source>
         <translation>Velg filnavn til reservekopien</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="489"/>
-        <location filename="../src/gui/mainwindow.cpp" line="496"/>
+        <location filename="../src/gui/mainwindow.cpp" line="491"/>
+        <location filename="../src/gui/mainwindow.cpp" line="498"/>
         <source>No file was selected.</source>
         <translation>Ingen fil ble valgt.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="494"/>
+        <location filename="../src/gui/mainwindow.cpp" line="496"/>
         <source>Select MBR or PBR backup file</source>
         <translation>Velg fil med MBR/PBR-reservekopi</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="512"/>
+        <location filename="../src/gui/mainwindow.cpp" line="514"/>
         <source>About %1</source>
         <translation>Om %1</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="514"/>
+        <location filename="../src/gui/mainwindow.cpp" line="516"/>
         <source>Version: </source>
         <translation>Versjon:</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="515"/>
+        <location filename="../src/gui/mainwindow.cpp" line="517"/>
         <source>Simple boot repair program for MX Linux</source>
         <translation>Oppstartsreparasjon for MX Linux</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="517"/>
+        <location filename="../src/gui/mainwindow.cpp" line="519"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Opphavsrett (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="518"/>
+        <location filename="../src/gui/mainwindow.cpp" line="520"/>
         <source>%1 License</source>
         <translation>Lisens for %1</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="531"/>
+        <location filename="../src/gui/mainwindow.cpp" line="533"/>
         <source>%1 Help</source>
         <translation>Hjelpetekst for %1</translation>
     </message>
@@ -368,78 +366,79 @@ Er du sikker?</translation>
     <message>
         <location filename="../src/gui/main.cpp" line="94"/>
         <source>MX Boot Repair - GUI and CLI tool for repairing GRUB bootloader</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Oppstartsreparasjon — Grafisk/kommandolinje-verktøy for reparering av oppstartslasteren GRUB</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="99"/>
         <source>Force CLI mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Tving kommandolinjemodus</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="100"/>
         <source>Print actions without executing</source>
-        <translation type="unfinished"></translation>
+        <translation>List ut handlinger uten å kjøre dem</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="101"/>
         <source>Do not prompt; require flags</source>
-        <translation type="unfinished"></translation>
+        <translation>Ikke spør; krev flagg</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="102"/>
         <source>Action: install, repair, initramfs, backup, restore</source>
-        <translation type="unfinished"></translation>
+        <translation>Handling: Installer, reparer, initramfs, reservekopier, gjenopprett</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="103"/>
         <source>Target for install: mbr, esp, root</source>
-        <translation type="unfinished"></translation>
+        <translation>Mål for installasjon: mbr, esp, root</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="104"/>
         <source>Device for target (e.g., sda, sda1)</source>
-        <translation type="unfinished"></translation>
+        <translation>Enhet for mål (f.eks. sda, sda1)</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="105"/>
         <source>Root partition (e.g., /dev/sda2)</source>
-        <translation type="unfinished"></translation>
+        <translation>Rotpartisjon (f.eks. /dev/sda2)</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="106"/>
         <source>Partition to mount at /boot in chroot</source>
-        <translation type="unfinished"></translation>
+        <translation>Partisjon som skal monteres på /boot i chroot</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="107"/>
         <source>Partition to mount at /boot/efi in chroot</source>
-        <translation type="unfinished"></translation>
+        <translation>Partisjon som skal monteres på /boot/efi i chroot</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="108"/>
         <source>Path for backup/restore image</source>
-        <translation type="unfinished"></translation>
+        <translation>Sti til reservekopi/gjenopprettings-avbildning</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="109"/>
         <source>Skip confirmations (for restore)</source>
-        <translation type="unfinished"></translation>
+        <translation>Hopp over bekreftelser (for gjenoppretting)</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="110"/>
         <source>Enable verbose output</source>
-        <translation type="unfinished"></translation>
+        <translation>Slå på meddelsom utdata</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="111"/>
         <source>Suppress non-error output</source>
-        <translation type="unfinished"></translation>
+        <translation>Hopp over utdata som ikke er relatert til feil</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="121"/>
         <source>Error: --verbose and --quiet options are mutually exclusive
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Feil: Alternativene --verbose og --quiet utelukker hverandre
+</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="127"/>
@@ -518,15 +517,15 @@ Er du sikker?</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="259"/>
-        <location filename="../src/cli/controller.cpp" line="294"/>
-        <location filename="../src/cli/controller.cpp" line="307"/>
+        <location filename="../src/cli/controller.cpp" line="297"/>
+        <location filename="../src/cli/controller.cpp" line="310"/>
         <source>No partitions found. Returning to main menu.</source>
         <translation>Fant ingen partisjoner. Går tilbake til hovedmenyen.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="263"/>
-        <location filename="../src/cli/controller.cpp" line="320"/>
-        <location filename="../src/cli/controller.cpp" line="338"/>
+        <location filename="../src/cli/controller.cpp" line="323"/>
+        <location filename="../src/cli/controller.cpp" line="341"/>
         <source>No disks found. Returning to main menu.</source>
         <translation>Fant ingen disker. Går tilbake til hovedmenyen.</translation>
     </message>
@@ -546,66 +545,66 @@ Er du sikker?</translation>
         <translation>Velg rotpartisjon for det installerte systemet</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="295"/>
+        <location filename="../src/cli/controller.cpp" line="298"/>
         <source>Select root partition to repair</source>
         <translation>Velg rotpartisjon som skal repareres</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="308"/>
+        <location filename="../src/cli/controller.cpp" line="311"/>
         <source>Select root partition to regenerate initramfs</source>
         <translation>Velg rotpartisjon for å regenerere initramfs</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="321"/>
+        <location filename="../src/cli/controller.cpp" line="324"/>
         <source>Select disk to back up MBR/PBR from</source>
         <translation>Velg disk som MBR/PBR skal reservekopieres fra</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="324"/>
+        <location filename="../src/cli/controller.cpp" line="327"/>
         <source>Output file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
         <translation>Sti til utdatafil (eller &apos;b&apos; for å gå tilbake, &apos;q&apos; for å avslutte):</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="339"/>
+        <location filename="../src/cli/controller.cpp" line="342"/>
         <source>Select disk to restore MBR/PBR to</source>
         <translation>Velg disk som MBR/PBR skal gjenopprettes til</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="342"/>
+        <location filename="../src/cli/controller.cpp" line="345"/>
         <source>Input backup file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
         <translation>Sti til inndatafil (eller &apos;b&apos; for å gå tilbake, &apos;q&apos; for å avslutte):</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="349"/>
+        <location filename="../src/cli/controller.cpp" line="352"/>
         <source>WARNING: This will overwrite the first 446 bytes of /dev/</source>
         <translation>ADVARSEL: Dette vil overskrive de første 446 byte av /dev/</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="349"/>
+        <location filename="../src/cli/controller.cpp" line="352"/>
         <source>. Continue? [y/N]: </source>
         <translation>. Fortsett? [y/N]:</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="352"/>
+        <location filename="../src/cli/controller.cpp" line="355"/>
         <source>yes</source>
         <comment>confirmation input: full word</comment>
         <translation>ja</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="353"/>
+        <location filename="../src/cli/controller.cpp" line="356"/>
         <source>y</source>
         <comment>confirmation input: single-letter yes</comment>
         <translation>j</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="357"/>
+        <location filename="../src/cli/controller.cpp" line="360"/>
         <source>Cancelled.</source>
         <translation>Avbrutt.</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="364"/>
+        <location filename="../src/cli/controller.cpp" line="367"/>
         <source>Unknown selection</source>
         <translation>Ukjent valg</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
